Skip to main content

ViteMaDose - CLI

Ce projet est un petit outil en ligne de commande, permettant de détecter les rendez-vous disponibles dans votre département pour recevoir un vaccin contre la covid19.

Basé sur les données de vitemadose.covidtracker.fr (dont je tiens à féliciter l'équipe par la même occasion!), ce projet ne vise pas à s'y substituer: Les données les plus détaillées et les mieux présentées sont accessibles via le site officiel, pas via cet outil.

Si un ou des rendez-vous sont disponibles, vous avez la possibilité de recevoir une notification sur votre téléphone, via les services de pushbullet.com.

NDLR: Pushbullet est assez simple à mettre en oeuvre et je l'utilisais déjà, d'où ce choix. Je ne doute pas que d'autres systèmes feraient aussi bien voir mieux. N'hésitez pas à faire des PR!

Le projet est en franglais car j'ai l'habitude de coder en Anglais mais la destination de ce projet est uniquement Française.

Installation

pip install vmdcli

Usage

vmd-cli --help
# Output
Usage: vmd-cli [OPTIONS]

  Look for available appointment(s) in the next X days in your departement.

Options:
  -v, --verbose         Enable verbose mode
  -q, --quiet           Quiet mode
  -c, --chrono          Only look for "chronodoses"
  -s, --watch INTEGER   Watch mode, sleep X seconds before replaying
  --days [1|2|7|28|49]  Number of days to look at for available appointment(s)
  --dept TEXT           Your departement number
  --pbtoken TEXT        Pushbullet token to send a notification
  --help                Show this message and exit.

Examples

Chercher un rendez-vous dans les 2 prochains jours dans le 33:

vmd-cli --days 2 --dept 33
# Output
Centre municipal de vaccination anti COVID-19 de la ville d'Arcachon: 2 available appointements in the next 2 days
  > https://www.doctolib.fr/centre-de-sante/arcachon/centre-municipal-de-vaccination-anti-covid-19-de-la-ville-d-arcachon?pid=practice-164885
  > Vaccins proposés: AstraZeneca
  > Type d'établissement: vaccination-center

Chercher une 'chronodose' dans un département:

vmd-cli --chrono --dept 33
# Output
Looking for available appointements in departement 33 for 'chronodoses'
Last data update: 4 minutes
CHU BORDEAUX - SITE PELLEGRIN: 1 'chronodoses' availables
  > https://vaccination-covid.keldoc.com/centre-hospitalier-universitaire/bordeaux-33000/chu-de-bordeaux?cabinet=16876&specialty=496
  > Vaccins proposés: Pfizer-BioNTech
  > Type d'établissement: vaccination-center

Chercher, toutes les 60 secondes, une 'chronodose' dans un département:

vmd-cli --chrono --dept 33 --watch 60

Notifications

Spécifiez un Token d'API Pushbullet via l'argument --pbtoken pour recevoir une notification sur votre téléphone.

vmd-cli --chrono --dept 35 --pbtoken "o.xxxxxxxxxxxxxxxxxxxxxxxxxxx"

Cron/Planification

Il est tout à fait possible de mettre la commande dans un gestionnaire de planification comme cron:

Par exemple pour recevoir une notification des centres de Gironde (33) avec des disponibilités pour une 'chronodose', avec une vérification toutes les heures:

crontab -e

# Ajoutez:
# m h   dom mon dow   command
00  *   *   *   *     vmd-cli --quiet --chrono --dept 33 --pbtoken "o.xxxxxxxxxxxxxxxxxxxxxxxxxxx"

Metadata

Release files for vmdcli 0.2.3

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for vmdcli 0.2.3
File Size Uploaded Provenance Actions
vmdcli-0.2.3.tar.gz 11.8 kB Without provenance Details for vmdcli-0.2.3.tar.gz

Built distribution (wheel)

Table of built distributions (wheels) for vmdcli 0.2.3
File Interpreter ABI Platform Actions
vmdcli-0.2.3-py2.py3-none-any.whl Python 3, Python 2 none any Details for vmdcli-0.2.3-py2.py3-none-any.whl

Total release size: 18.7 kB

Release files / vmdcli-0.2.3.tar.gz

Download URL vmdcli-0.2.3.tar.gz
Size 11.8 kB
Tags Source
SHA-256 checksum
How to use checksums
3b7e08acff5ecde7d19f7fe20d376c0812921679e4c68a2be46695af89a3205d
BLAKE2b-256 checksum
How to use checksums
b8f663668583b0aafa45038ffa1e2aa7a3d7e5f299875d5230777f64288f6de6
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.4.1 importlib_metadata/4.2.0 pkginfo/1.7.0 requests/2.25.1 requests-toolbelt/0.9.1 tqdm/4.61.0 CPython/3.8.10

Release files / vmdcli-0.2.3-py2.py3-none-any.whl

Download URL vmdcli-0.2.3-py2.py3-none-any.whl
Size 6.9 kB
Tags Python 2 Python 3
SHA-256 checksum
How to use checksums
482689daf4889a1da680c7f95166b842bd2c93eb8511e4949e946d760af852bc
BLAKE2b-256 checksum
How to use checksums
863dce940b7da44be2cce6c654576c039c736ea1ba5764666b18085a0512c332
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/3.4.1 importlib_metadata/4.2.0 pkginfo/1.7.0 requests/2.25.1 requests-toolbelt/0.9.1 tqdm/4.61.0 CPython/3.8.10

Security for vmdcli 0.2.3

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

No provenance found

None of the files in this release were uploaded with provenance metadata.

A note on package security

PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.

To learn more about protecting yourself from malicious actors, visit our package security documentation.

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page